.. -*- coding: utf-8 -*-

.. _contents:

=======================
PyBill Developer Manual
=======================

.. automodule:: pybill

.. toctree::
   :maxdepth: 2

   pybill_index
   commandline_index
   lib_index
